@@ -117,7 +117,16 @@ class Configurable:
 
         # get config values and default values
         values = dict(nest.__dict__)
-        defaults = values['__annotations__']
+
+        # remove non-values
+        for key, _ in values.copy().items():
+            if key.startswith('__'):
+                del values[key]
+
+        # stop if no values
+        if not values: return
+
+        defaults = nest.__dict__['__annotations__']
 
         # remove non-values
         for key, _ in values.copy().items():
@@ -140,4 +149,4 @@ class Configurable:
                 self._generate_config(value, destination[value.__name__])
 
     def _parse_error(self, option, message):
-        print(f"Error while trying to load option '{option}': {message}")
\ No newline at end of file
+        print(f"Error while trying to load option '{option}': {message}")
